Documentation
¶
Overview ¶
Package lpc provides a linear predictive coding interface.
The LPC modelling algorithm is based on the autocorrelation method with the addition of a numerical tweak to enforce stability of the resulting model.
Package lpc supports modelling, predicting and generation/synthesis.
Package lpc does not yet support line spectral frequencies or conversion to other coefficient representations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type State ¶
type State struct {
// contains filtered or unexported fields
}
State encapsulates linear prediction state for incremental usage in synthesis and prediction.
func (*State) Consume ¶
Consume advances the state one element (d), and returns the residue of the model for d.
type T ¶
type T struct {
// contains filtered or unexported fields
}
T holds states for doing linear predictive coding of a given order.
func (*T) Residue ¶
Residue applies the model to d and for d[p.Order():] replaces the value of the input with the error (aka residue) of the model.